@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/macro.c,v 1.7 2012/12/22 00:06:11 tg Exp $ */
+/* $MirOS: contrib/code/jupp/macro.c,v 1.8 2017/03/19 19:19:50 tg Exp $ */
 /*
  *	Keyboard macros
  *	Copyright
@@ -582,8 +582,8 @@ static int doarg(BW *bw, unsigned char *s, void *object, int *notify)
 	if (notify)
 		*notify = 1;
 	num = calc(bw, s);
-	if (merr) {
-		msgnw(bw->parent, merr);
+	if (merrf) {
+		msgnw(bw->parent, merrt);
 		return -1;
 	}
 	arg = num;
