@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/path.h,v 1.8 2013/08/19 22:48:33 tg Exp $ */
+/* $MirOS: contrib/code/jupp/path.h,v 1.11 2016/10/29 23:44:45 tg Exp $ */
 /*
  *	Directory and path functions
  *	Copyright
@@ -11,7 +11,30 @@
 
 #include "config.h"
 
+#if defined(__MSDOS__) || defined(__DJGPP__) || defined(__EMX__) || \
+    defined(__CYGWIN__) || defined(_WIN32)
+/*XXX check this for all platforms */
+#define HAVE_BACKSLASH_PATHS 1
+#define HAVE_DRIVE_LETTERS 1
+#else
+#define HAVE_BACKSLASH_PATHS 0
+#define HAVE_DRIVE_LETTERS 0
+#endif
+
+#if HAVE_BACKSLASH_PATHS
 unsigned char *joesep PARAMS((unsigned char *path));
+#else
+#define joesep(path) (path)
+#endif
+
+#if JUPP_WIN32RELOC
+extern unsigned char has_JOERC, *get_JOERC;
+void init_JOERC PARAMS((void));
+#else
+#define has_JOERC	1
+#define get_JOERC	JOERC
+#define init_JOERC()	/* nothing */
+#endif
 
 /* char *namprt(char *path);
  * Return name part of a path.  There is no name if the last character
@@ -103,7 +126,8 @@ int isreg PARAMS((unsigned char *s));
  */
 unsigned char **rexpnd PARAMS((unsigned char *word));
 
-int chpwd PARAMS((unsigned char *path));
+int chJpwd PARAMS((const unsigned char *path));
+int chpwd PARAMS((const unsigned char *path));
 unsigned char *pwd PARAMS((void));
 
 #endif
